@@ -5,7 +5,6 @@ from typing import Any, Dict
 
 from dvc_objects.fs.base import ObjectFileSystem
 from dvc_objects.fs.errors import AuthError
-from fsspec.asyn import fsspec_loop
 from fsspec.utils import infer_storage_options
 from funcy import cached_property, memoize, wrap_prop
 
@@ -57,7 +56,11 @@ class AzureFileSystem(ObjectFileSystem):
     def _strip_protocol(cls, path: str):
         opts = infer_storage_options(path)
         if opts.get("host"):
-            return "{host}{path}".format(**opts)
+            if "url_query" in opts:
+                query = f"?{opts['url_query']}"
+            else:
+                query = ""
+            return f"{opts['host']}{opts['path']}{query}"
 
         return _az_config().get("storage", "container_name", None)
 
@@ -120,22 +123,21 @@ class AzureFileSystem(ObjectFileSystem):
             and not any_secondary
             and not config.get("allow_anonymous_login", False)
         ):
-            with fsspec_loop():
-                login_info["credential"] = DefaultAzureCredential(
-                    exclude_interactive_browser_credential=False,
-                    exclude_environment_credential=config.get(
-                        "exclude_environment_credential", False
-                    ),
-                    exclude_visual_studio_code_credential=config.get(
-                        "exclude_visual_studio_code_credential", False
-                    ),
-                    exclude_shared_token_cache_credential=config.get(
-                        "exclude_shared_token_cache_credential", False
-                    ),
-                    exclude_managed_identity_credential=config.get(
-                        "exclude_managed_identity_credential", False
-                    ),
-                )
+            login_info["credential"] = DefaultAzureCredential(
+                exclude_interactive_browser_credential=False,
+                exclude_environment_credential=config.get(
+                    "exclude_environment_credential", False
+                ),
+                exclude_visual_studio_code_credential=config.get(
+                    "exclude_visual_studio_code_credential", False
+                ),
+                exclude_shared_token_cache_credential=config.get(
+                    "exclude_shared_token_cache_credential", False
+                ),
+                exclude_managed_identity_credential=config.get(
+                    "exclude_managed_identity_credential", False
+                ),
+            )
 
         for login_method, required_keys in [  # noqa
             ("connection string", ["connection_string"]),
@@ -162,10 +164,9 @@ class AzureFileSystem(ObjectFileSystem):
     @wrap_prop(threading.Lock())
     @cached_property
     def fs(self):
+        from adlfs import AzureBlobFileSystem
         from azure.core.exceptions import AzureError
 
-        from ._spec import AzureBlobFileSystem
-
         try:
             return AzureBlobFileSystem(**self.fs_args)
         except (ValueError, AzureError) as e:
@@ -173,3 +174,7 @@ class AzureFileSystem(ObjectFileSystem):
                 f"Authentication to Azure Blob Storage via {self.login_method}"
                 " failed."
             ) from e
+
+    def put_file(self, *args, **kwargs) -> None:
+        kwargs["overwrite"] = True
+        super().put_file(*args, **kwargs)
